==> cdktf-cdktf-provider-datadog-0.2.52.tar.gz: package/lib/data-datadog-security-monitoring-filters.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataDatadogSecurityMonitoringFiltersConfig extends cdktf.TerraformMetaArguments {
}
/**
 * @stability stable
 */
export declare class DataDatadogSecurityMonitoringFiltersFiltersExclusionFilter extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get query(): string;
}
/**
 * @stability stable
 */
export declare class DataDatadogSecurityMonitoringFiltersFilters extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get exclusionFilter(): any;
    /**
     * @stability stable
     */
    get filteredDataType(): string;
    /**
     * @stability stable
     */
    get isEnabled(): any;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    get version(): number;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/d/security_monitoring_filters.html datadog_security_monitoring_filters}.
 *
 * @stability stable
 */
export declare class DataDatadogSecurityMonitoringFilters extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/d/security_monitoring_filters.html datadog_security_monitoring_filters} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataDatadogSecurityMonitoringFiltersConfig);
    /**
     * @stability stable
     */
    filters(index: string): DataDatadogSecurityMonitoringFiltersFilters;
    /**
     * @stability stable
     */
    get filtersIds(): string[];
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-datadog-0.4.1.tar.gz: package/lib/data-datadog-security-monitoring-filters.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataDatadogSecurityMonitoringFiltersConfig extends cdktf.TerraformMetaArguments {
}
/**
 * @stability stable
 */
export declare class DataDatadogSecurityMonitoringFiltersFiltersExclusionFilter extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get query(): string;
}
/**
 * @stability stable
 */
export declare class DataDatadogSecurityMonitoringFiltersFilters extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get exclusionFilter(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get filteredDataType(): string;
    /**
     * @stability stable
     */
    get isEnabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    get version(): number;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/d/security_monitoring_filters datadog_security_monitoring_filters}.
 *
 * @stability stable
 */
export declare class DataDatadogSecurityMonitoringFilters extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/d/security_monitoring_filters datadog_security_monitoring_filters} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataDatadogSecurityMonitoringFiltersConfig);
    /**
     * @stability stable
     */
    filters(index: string): DataDatadogSecurityMonitoringFiltersFilters;
    /**
     * @stability stable
     */
    get filtersIds(): string[];
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
